pub struct DirectoryListItems {
pub description: Option<String>,
pub discovery_link: Option<String>,
pub discovery_rest_url: Option<String>,
pub documentation_link: Option<String>,
pub icons: Option<DirectoryListItemsIcons>,
pub id: Option<String>,
pub kind: Option<String>,
pub labels: Option<Vec<String>>,
pub name: Option<String>,
pub preferred: Option<bool>,
pub title: Option<String>,
pub version: Option<String>,
}Expand description
The individual directory entries. One entry per api/version pair.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>The description of this API.
discovery_link: Option<String>A link to the discovery document.
discovery_rest_url: Option<String>The URL for the discovery REST document.
documentation_link: Option<String>A link to human readable documentation for the API.
icons: Option<DirectoryListItemsIcons>Links to 16x16 and 32x32 icons representing the API.
id: Option<String>The id of this API.
kind: Option<String>The kind for this response.
labels: Option<Vec<String>>Labels for the status of this API, such as labs or deprecated.
name: Option<String>The name of the API.
preferred: Option<bool>True if this version is the preferred version to use.
title: Option<String>The title of this API.
version: Option<String>The version of the API.