pub struct JsonSchemaVariant {
pub discriminant: Option<String>,
pub map: Option<Vec<JsonSchemaVariantMap>>,
}Expand description
In a variant data type, the value of one property is used to determine how to interpret the entire entity. Its value must exist in a map of descriminant values to schema names.
This type is not used in any activity, and only used as part of another schema.
Fields
discriminant: Option<String>The name of the type discriminant property.
map: Option<Vec<JsonSchemaVariantMap>>The map of discriminant value to schema to use for parsing..