pub struct RestDescriptionEndpoints {
pub deprecated: Option<bool>,
pub description: Option<String>,
pub endpoint_url: Option<String>,
pub location: Option<String>,
}Expand description
A single endpoint object
This type is not used in any activity, and only used as part of another schema.
Fields
deprecated: Option<bool>Whether this endpoint is deprecated
description: Option<String>A string describing the host designated by the URL
endpoint_url: Option<String>The URL of the endpoint target host
location: Option<String>The location of the endpoint