RestMethod

Struct RestMethod 

pub struct RestMethod {
Show 18 fields pub api_version: Option<String>, pub deprecated: Option<bool>, pub description: Option<String>, pub etag_required: Option<bool>, pub flat_path: Option<String>, pub http_method: Option<String>, pub id: Option<String>, pub media_upload: Option<RestMethodMediaUpload>, pub parameter_order: Option<Vec<String>>, pub parameters: Option<HashMap<String, JsonSchema>>, pub path: Option<String>, pub request: Option<RestMethodRequest>, pub response: Option<RestMethodResponse>, pub scopes: Option<Vec<String>>, pub supports_media_download: Option<bool>, pub supports_media_upload: Option<bool>, pub supports_subscription: Option<bool>, pub use_media_download_service: Option<bool>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

api_version: Option<String>

The API Version of this method, as passed in via the X-Goog-Api-Version header or $apiVersion query parameter.

deprecated: Option<bool>

Whether this method is deprecated.

description: Option<String>

Description of this method.

etag_required: Option<bool>

Whether this method requires an ETag to be specified. The ETag is sent as an HTTP If-Match or If-None-Match header.

flat_path: Option<String>

The URI path of this REST method in (RFC 6570) format without level 2 features ({+var}). Supplementary to the path property.

http_method: Option<String>

HTTP method used by this method.

id: Option<String>

A unique ID for this method. This property can be used to match methods between different versions of Discovery.

media_upload: Option<RestMethodMediaUpload>

Media upload parameters.

parameter_order: Option<Vec<String>>

Ordered list of required parameters, serves as a hint to clients on how to structure their method signatures. The array is ordered such that the “most-significant” parameter appears first.

parameters: Option<HashMap<String, JsonSchema>>

Details for all parameters in this method.

path: Option<String>

The URI path of this REST method. Should be used in conjunction with the basePath property at the api-level.

request: Option<RestMethodRequest>

The schema for the request.

response: Option<RestMethodResponse>

The schema for the response.

scopes: Option<Vec<String>>

OAuth 2.0 scopes applicable to this method.

supports_media_download: Option<bool>

Whether this method supports media downloads.

supports_media_upload: Option<bool>

Whether this method supports media uploads.

supports_subscription: Option<bool>

Whether this method supports subscriptions.

use_media_download_service: Option<bool>

Indicates that downloads from this method should use the download service URL (i.e. “/download”). Only applies if the method supports media download.